@@ -156,6 +156,13 @@ named_server_reloadcommand(named_server_t *server, isc_lex_t *lex,
  * Act on a "reload" command from the command channel.
  */
 
+isc_result_t
+named_server_resetstatscommand(named_server_t *server, isc_lex_t *lex,
+			       isc_buffer_t **text);
+/*%<
+ * Act on a "reset-stats" command from the command channel.
+ */
+
 isc_result_t
 named_server_reconfigcommand(named_server_t *server);
 /*%<
