@@ -48,10 +48,6 @@ def is_dnsrps_available():
     return True
 
 
-def with_dnstap(*args):  # pylint: disable=unused-argument
-    return feature_test("--enable-dnstap")
-
-
 def with_tsan(*args):  # pylint: disable=unused-argument
     return feature_test("--tsan")
 
@@ -62,6 +58,11 @@ def with_algorithm(name: str):
     return pytest.mark.skipif(os.getenv(key) != "1", reason=f"{name} is not supported")
 
 
+with_dnstap = pytest.mark.skipif(
+    not feature_test("--enable-dnstap"), reason="DNSTAP support disabled in the build"
+)
+
+
 without_fips = pytest.mark.skipif(
     feature_test("--have-fips-mode"), reason="FIPS support enabled in the build"
 )
