@@ -9,9 +9,7 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-import dns.rrset
 import dns.zone
-import pytest
 
 
 def zone_contains(
@@ -42,9 +40,3 @@ def file_contents_contain(file, substr):
             if f"{substr}" in line:
                 return True
     return False
-
-
-def param(*args, **kwargs):
-    if "id" not in kwargs:
-        kwargs["id"] = args[0]  # use first argument  as test ID
-    return pytest.param(*args, **kwargs)
