@@ -72,7 +72,7 @@ fromtext_nxt(ARGS_FROMTEXT) {
 		 * NXT is only specified for types 1..127.
 		 */
 		if (covered < 1 || covered > 127) {
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		if (first || covered > maxcovered) {
 			maxcovered = covered;
@@ -82,10 +82,10 @@ fromtext_nxt(ARGS_FROMTEXT) {
 	} while (1);
 	isc_lex_ungettoken(lexer, &token);
 	if (first) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	n = (maxcovered + 8) / 8;
-	return (mem_tobuffer(target, bm, n));
+	return mem_tobuffer(target, bm, n);
 }
 
 static isc_result_t
@@ -131,7 +131,7 @@ totext_nxt(ARGS_TOTEXT) {
 			}
 		}
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -153,11 +153,11 @@ fromwire_nxt(ARGS_FROMWIRE) {
 	if (sr.length > 0 && ((sr.base[0] & 0x80) != 0 || sr.length > 16 ||
 			      sr.base[sr.length - 1] == 0))
 	{
-		return (DNS_R_BADBITMAP);
+		return DNS_R_BADBITMAP;
 	}
 	RETERR(mem_tobuffer(target, sr.base, sr.length));
 	isc_buffer_forward(source, sr.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -176,7 +176,7 @@ towire_nxt(ARGS_TOWIRE) {
 	isc_region_consume(&sr, name_length(&name));
 	RETERR(dns_name_towire(&name, cctx, target, NULL));
 
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -201,13 +201,13 @@ compare_nxt(ARGS_COMPARE) {
 	dns_name_fromregion(&name2, &r2);
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&r1, name_length(&name1));
 	isc_region_consume(&r2, name_length(&name2));
 
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -231,7 +231,7 @@ fromstruct_nxt(ARGS_FROMSTRUCT) {
 	dns_name_toregion(&nxt->next, &region);
 	RETERR(isc_buffer_copyregion(target, &region));
 
-	return (mem_tobuffer(target, nxt->typebits, nxt->len));
+	return mem_tobuffer(target, nxt->typebits, nxt->len);
 }
 
 static isc_result_t
@@ -258,7 +258,7 @@ tostruct_nxt(ARGS_TOSTRUCT) {
 	nxt->len = region.length;
 	nxt->typebits = mem_maybedup(mctx, region.base, region.length);
 	nxt->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -288,7 +288,7 @@ additionaldata_nxt(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -304,11 +304,11 @@ digest_nxt(ARGS_DIGEST) {
 	dns_name_fromregion(&name, &r);
 	result = dns_name_digest(&name, digest, arg);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_region_consume(&r, name_length(&name));
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -320,7 +320,7 @@ checkowner_nxt(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -331,11 +331,11 @@ checknames_nxt(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_nxt(ARGS_COMPARE) {
-	return (compare_nxt(rdata1, rdata2));
+	return compare_nxt(rdata1, rdata2);
 }
 #endif /* RDATA_GENERIC_NXT_30_C */
