@@ -57,7 +57,7 @@ fromtext_rt(ARGS_FROMTEXT) {
 	if (!ok && callbacks != NULL) {
 		warn_badname(&name, lexer, callbacks);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -84,7 +84,7 @@ totext_rt(ARGS_TOTEXT) {
 	dns_name_fromregion(&name, &region);
 	opts = name_prefix(&name, tctx->origin, &prefix) ? DNS_NAME_OMITFINALDOT
 							 : 0;
-	return (dns_name_totext(&prefix, opts, target));
+	return dns_name_totext(&prefix, opts, target);
 }
 
 static isc_result_t
@@ -105,15 +105,15 @@ fromwire_rt(ARGS_FROMWIRE) {
 	isc_buffer_activeregion(source, &sregion);
 	isc_buffer_availableregion(target, &tregion);
 	if (tregion.length < 2) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	if (sregion.length < 2) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	memmove(tregion.base, sregion.base, 2);
 	isc_buffer_forward(source, 2);
 	isc_buffer_add(target, 2);
-	return (dns_name_fromwire(&name, source, dctx, target));
+	return dns_name_fromwire(&name, source, dctx, target);
 }
 
 static isc_result_t
@@ -130,7 +130,7 @@ towire_rt(ARGS_TOWIRE) {
 	isc_buffer_availableregion(target, &tr);
 	dns_rdata_toregion(rdata, &region);
 	if (tr.length < 2) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(tr.base, region.base, 2);
 	isc_region_consume(&region, 2);
@@ -139,7 +139,7 @@ towire_rt(ARGS_TOWIRE) {
 	dns_name_init(&name, offsets);
 	dns_name_fromregion(&name, &region);
 
-	return (dns_name_towire(&name, cctx, target, NULL));
+	return dns_name_towire(&name, cctx, target, NULL);
 }
 
 static int
@@ -158,7 +158,7 @@ compare_rt(ARGS_COMPARE) {
 
 	order = memcmp(rdata1->data, rdata2->data, 2);
 	if (order != 0) {
-		return (order < 0 ? -1 : 1);
+		return order < 0 ? -1 : 1;
 	}
 
 	dns_name_init(&name1, NULL);
@@ -173,7 +173,7 @@ compare_rt(ARGS_COMPARE) {
 	dns_name_fromregion(&name1, &region1);
 	dns_name_fromregion(&name2, &region2);
 
-	return (dns_name_rdatacompare(&name1, &name2));
+	return dns_name_rdatacompare(&name1, &name2);
 }
 
 static isc_result_t
@@ -191,7 +191,7 @@ fromstruct_rt(ARGS_FROMSTRUCT) {
 
 	RETERR(uint16_tobuffer(rt->preference, target));
 	dns_name_toregion(&rt->host, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
 static isc_result_t
@@ -217,7 +217,7 @@ tostruct_rt(ARGS_TOSTRUCT) {
 	name_duporclone(&name, mctx, &rt->host);
 
 	rt->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -253,13 +253,13 @@ additionaldata_rt(ARGS_ADDLDATA) {
 
 	result = (add)(arg, &name, dns_rdatatype_x25, NULL DNS__DB_FILELINE);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	result = (add)(arg, &name, dns_rdatatype_isdn, NULL DNS__DB_FILELINE);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
-	return ((add)(arg, &name, dns_rdatatype_a, NULL DNS__DB_FILELINE));
+	return (add)(arg, &name, dns_rdatatype_a, NULL DNS__DB_FILELINE);
 }
 
 static isc_result_t
@@ -276,11 +276,11 @@ digest_rt(ARGS_DIGEST) {
 	r1.length = 2;
 	result = (digest)(arg, &r1);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &r2);
-	return (dns_name_digest(&name, digest, arg));
+	return dns_name_digest(&name, digest, arg);
 }
 
 static bool
@@ -292,7 +292,7 @@ checkowner_rt(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -312,14 +312,14 @@ checknames_rt(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
 static int
 casecompare_rt(ARGS_COMPARE) {
-	return (compare_rt(rdata1, rdata2));
+	return compare_rt(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_RT_21_C */
