@@ -29,7 +29,7 @@ fromtext_in_eid(ARGS_FROMTEXT) {
 	UNUSED(rdclass);
 	UNUSED(callbacks);
 
-	return (isc_hex_tobuffer(lexer, target, -2));
+	return isc_hex_tobuffer(lexer, target, -2);
 }
 
 static isc_result_t
@@ -54,7 +54,7 @@ totext_in_eid(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -70,12 +70,12 @@ fromwire_in_eid(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &region);
 	if (region.length < 1) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	RETERR(mem_tobuffer(target, region.base, region.length));
 	isc_buffer_forward(source, region.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -86,7 +86,7 @@ towire_in_eid(ARGS_TOWIRE) {
 
 	UNUSED(cctx);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
 static int
@@ -103,7 +103,7 @@ compare_in_eid(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -120,7 +120,7 @@ fromstruct_in_eid(ARGS_FROMSTRUCT) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	return (mem_tobuffer(target, eid->eid, eid->eid_len));
+	return mem_tobuffer(target, eid->eid, eid->eid_len);
 }
 
 static isc_result_t
@@ -141,7 +141,7 @@ tostruct_in_eid(ARGS_TOSTRUCT) {
 	eid->eid_len = r.length;
 	eid->eid = mem_maybedup(mctx, r.base, r.length);
 	eid->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -172,7 +172,7 @@ additionaldata_in_eid(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -184,7 +184,7 @@ digest_in_eid(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -197,7 +197,7 @@ checkowner_in_eid(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -209,12 +209,12 @@ checknames_in_eid(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_in_eid(ARGS_COMPARE) {
-	return (compare_in_eid(rdata1, rdata2));
+	return compare_in_eid(rdata1, rdata2);
 }
 
 #endif /* RDATA_IN_1_EID_31_C */
