@@ -108,10 +108,10 @@ dns_rdatalist_first(dns_rdataset_t *rdataset) {
 	rdataset->rdlist.iter = ISC_LIST_HEAD(rdatalist->rdata);
 
 	if (rdataset->rdlist.iter == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -120,16 +120,16 @@ dns_rdatalist_next(dns_rdataset_t *rdataset) {
 
 	rdata = rdataset->rdlist.iter;
 	if (rdata == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
 	rdataset->rdlist.iter = ISC_LIST_NEXT(rdata, link);
 
 	if (rdataset->rdlist.iter == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -170,7 +170,7 @@ dns_rdatalist_count(dns_rdataset_t *rdataset) {
 		count++;
 	}
 
-	return (count);
+	return count;
 }
 
 isc_result_t
@@ -195,7 +195,7 @@ dns_rdatalist_addnoqname(dns_rdataset_t *rdataset, const dns_name_t *name) {
 		}
 	}
 	if (neg == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	for (rdset = ISC_LIST_HEAD(name->list); rdset != NULL;
@@ -209,7 +209,7 @@ dns_rdatalist_addnoqname(dns_rdataset_t *rdataset, const dns_name_t *name) {
 	}
 
 	if (negsig == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 	/*
 	 * Minimise ttl.
@@ -224,7 +224,7 @@ dns_rdatalist_addnoqname(dns_rdataset_t *rdataset, const dns_name_t *name) {
 	rdataset->ttl = neg->ttl = negsig->ttl = ttl;
 	rdataset->attributes |= DNS_RDATASETATTR_NOQNAME;
 	rdataset->rdlist.noqname = name;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -257,7 +257,7 @@ dns_rdatalist_getnoqname(dns_rdataset_t *rdataset, dns_name_t *name,
 		}
 	}
 	if (tneg == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	for (rdataset = ISC_LIST_HEAD(noqname->list); rdataset != NULL;
@@ -270,13 +270,13 @@ dns_rdatalist_getnoqname(dns_rdataset_t *rdataset, dns_name_t *name,
 		}
 	}
 	if (tnegsig == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	dns_name_clone(noqname, name);
 	dns_rdataset_clone(tneg, neg);
 	dns_rdataset_clone(tnegsig, negsig);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -301,7 +301,7 @@ dns_rdatalist_addclosest(dns_rdataset_t *rdataset, const dns_name_t *name) {
 		}
 	}
 	if (neg == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	for (rdset = ISC_LIST_HEAD(name->list); rdset != NULL;
@@ -315,7 +315,7 @@ dns_rdatalist_addclosest(dns_rdataset_t *rdataset, const dns_name_t *name) {
 	}
 
 	if (negsig == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 	/*
 	 * Minimise ttl.
@@ -330,7 +330,7 @@ dns_rdatalist_addclosest(dns_rdataset_t *rdataset, const dns_name_t *name) {
 	rdataset->ttl = neg->ttl = negsig->ttl = ttl;
 	rdataset->attributes |= DNS_RDATASETATTR_CLOSEST;
 	rdataset->rdlist.closest = name;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -363,7 +363,7 @@ dns_rdatalist_getclosest(dns_rdataset_t *rdataset, dns_name_t *name,
 		}
 	}
 	if (tneg == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	for (rdataset = ISC_LIST_HEAD(closest->list); rdataset != NULL;
@@ -376,13 +376,13 @@ dns_rdatalist_getclosest(dns_rdataset_t *rdataset, dns_name_t *name,
 		}
 	}
 	if (tnegsig == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	dns_name_clone(closest, name);
 	dns_rdataset_clone(tneg, neg);
 	dns_rdataset_clone(tnegsig, negsig);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
