@@ -140,8 +140,6 @@ static void
 shutdown_trigger_close_cb(uv_handle_t *handle) {
 	isc_loop_t *loop = uv_handle_get_data(handle);
 
-	loop->shuttingdown = true;
-
 	isc_loop_detach(&loop);
 }
 
@@ -167,6 +165,9 @@ shutdown_cb(uv_async_t *handle) {
 	/* Make sure, we can't be called again */
 	uv_close(&loop->shutdown_trigger, shutdown_trigger_close_cb);
 
+	/* Mark this loop as shutting down */
+	loop->shuttingdown = true;
+
 	if (DEFAULT_LOOP(loopmgr) == CURRENT_LOOP(loopmgr)) {
 		/* Stop the signal handlers */
 		isc_signal_stop(loopmgr->sigterm);
@@ -290,7 +291,7 @@ helper_thread(void *arg) {
 
 	isc_barrier_wait(&helper->loopmgr->stopping);
 
-	return (NULL);
+	return NULL;
 }
 
 static void *
@@ -338,7 +339,7 @@ loop_thread(void *arg) {
 
 	isc_barrier_wait(&loopmgr->stopping);
 
-	return (NULL);
+	return NULL;
 }
 
 /**
@@ -438,7 +439,7 @@ isc_loop_setup(isc_loop_t *loop, isc_job_cb cb, void *cbarg) {
 	cds_wfcq_enqueue(&loop->setup_jobs.head, &loop->setup_jobs.tail,
 			 &job->wfcq_node);
 
-	return (job);
+	return job;
 }
 
 isc_job_t *
@@ -459,7 +460,7 @@ isc_loop_teardown(isc_loop_t *loop, isc_job_cb cb, void *cbarg) {
 	cds_wfcq_enqueue(&loop->teardown_jobs.head, &loop->teardown_jobs.tail,
 			 &job->wfcq_node);
 
-	return (job);
+	return job;
 }
 
 void
@@ -628,21 +629,21 @@ uint32_t
 isc_loopmgr_nloops(isc_loopmgr_t *loopmgr) {
 	REQUIRE(VALID_LOOPMGR(loopmgr));
 
-	return (loopmgr->nloops);
+	return loopmgr->nloops;
 }
 
 isc_mem_t *
 isc_loop_getmctx(isc_loop_t *loop) {
 	REQUIRE(VALID_LOOP(loop));
 
-	return (loop->mctx);
+	return loop->mctx;
 }
 
 isc_loop_t *
 isc_loop_main(isc_loopmgr_t *loopmgr) {
 	REQUIRE(VALID_LOOPMGR(loopmgr));
 
-	return (DEFAULT_LOOP(loopmgr));
+	return DEFAULT_LOOP(loopmgr);
 }
 
 isc_loop_t *
@@ -650,7 +651,7 @@ isc_loop_get(isc_loopmgr_t *loopmgr, uint32_t tid) {
 	REQUIRE(VALID_LOOPMGR(loopmgr));
 	REQUIRE(tid < loopmgr->nloops);
 
-	return (LOOP(loopmgr, tid));
+	return LOOP(loopmgr, tid);
 }
 
 void
@@ -673,7 +674,7 @@ isc_loopmgr_t *
 isc_loop_getloopmgr(isc_loop_t *loop) {
 	REQUIRE(VALID_LOOP(loop));
 
-	return (loop->loopmgr);
+	return loop->loopmgr;
 }
 
 isc_time_t
@@ -686,7 +687,7 @@ isc_loop_now(isc_loop_t *loop) {
 		.nanoseconds = (msec % MS_PER_SEC) * NS_PER_MS,
 	};
 
-	return (t);
+	return t;
 }
 
 bool
@@ -694,5 +695,5 @@ isc_loop_shuttingdown(isc_loop_t *loop) {
 	REQUIRE(VALID_LOOP(loop));
 	REQUIRE(loop->tid == isc_tid());
 
-	return (loop->shuttingdown);
+	return loop->shuttingdown;
 }
